@@ -1,14 +1,14 @@
 package Org::To::HTML;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2016-11-06'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 use 5.010;
 use Log::Any::IfLOG '$log';
 
 use vars qw($VERSION);
 
-use File::Slurp::Tiny qw(read_file);
+use File::Slurper qw(read_text);
 use HTML::Entities qw/encode_entities/;
 use Org::Document;
 
@@ -93,6 +93,9 @@ _
             summary => 'Don\'t wrap exported HTML with HTML/HEAD/BODY elements',
             schema => ['bool' => {}],
         },
+        ignore_unknown_settings => {
+            schema => 'bool',
+        },
     },
 };
 sub org_to_html {
@@ -100,8 +103,10 @@ sub org_to_html {
 
     my $doc;
     if ($args{source_file}) {
-        $doc = Org::Document->new(from_string =>
-                                      scalar read_file($args{source_file}));
+        $doc = Org::Document->new(
+            from_string => scalar read_text($args{source_file}),
+            ignore_unknown_settings => $args{ignore_unknown_settings},
+        );
     } elsif (defined($args{source_str})) {
         $doc = Org::Document->new(from_string => $args{source_str});
     } else {
@@ -392,7 +397,7 @@ Org::To::HTML - Export Org document to HTML
 
 =head1 VERSION
 
-This document describes version 0.16 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2015-09-03.
+This document describes version 0.17 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2016-11-06.
 
 =head1 SYNOPSIS
 
@@ -420,6 +425,12 @@ Export Org format to HTML. To customize, you can subclass this module.
 
 A command-line utility is included: L<org-to-html>.
 
+=head1 new(%args)
+
+=head2 $exp->export_document($doc) => HTML
+
+Export document to HTML.
+
 =head1 FUNCTIONS
 
 
@@ -430,6 +441,8 @@ Export Org document to HTML.
 This is the non-OO interface. For more customization, consider subclassing
 Org::To::HTML.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -453,6 +466,8 @@ exclude_tags is evaluated after include_tags.
 
 HTML document title, defaults to source_file.
 
+=item * B<ignore_unknown_settings> => I<bool>
+
 =item * B<include_tags> => I<array[str]>
 
 Include trees that carry one of these tags.
@@ -514,27 +529,13 @@ If set, export_document() will output a LINK element pointing to this CSS.
 
 =head1 METHODS
 
-=head1 new(%args)
-
-=head2 $exp->export_document($doc) => HTML
-
-Export document to HTML.
-
-=head1 SEE ALSO
-
-For more information about Org document format, visit http://orgmode.org/
-
-L<Org::Parser>
-
-L<org-to-html>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Org-To-HTML>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Org-To-HTML>.
+Source repository is at L<https://github.com/sharyanto/perl-Org-To-HTML>.
 
 =head1 BUGS
 
@@ -544,13 +545,21 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+For more information about Org document format, visit http://orgmode.org/
+
+L<Org::Parser>
+
+L<org-to-html>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
